==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
export let DataGridSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridSummaryResultDescriptionMetadata.a == null) {
                DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
            }
            if (a.j(DataGridSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.y(DataGridSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
            a.item("Value", "Unknown");
            a.item("SummaryIndex", "Number:int");
        }
        static d(a) {
            DataGridSummaryResultDescriptionMetadata.b(a);
            a.aa("DataGridSummaryResult", () => new DataGridSummaryResultDescription());
            a.z("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
        }
    }
    DataGridSummaryResultDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataGridSummaryResultDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridSummaryResultDescription } from "./DataGridSummaryResultDescription";
/**
 * @hidden
 */
export let DataGridSummaryResultDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataGridSummaryResultDescriptionMetadata extends Base {
        static b(a) {
            if (DataGridSummaryResultDescriptionMetadata.a == null) {
                DataGridSummaryResultDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataGridSummaryResultDescriptionMetadata.c(DataGridSummaryResultDescriptionMetadata.a);
            }
            if (a.k(DataGridSummaryResultDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataGridSummaryResultDescriptionMetadata.a);
        }
        static c(a) {
            a.item("GroupKeyRef", "(w:GroupKey,wf:GroupKey)DataRef:object");
            a.item("Value", "Unknown");
            a.item("SummaryIndex", "Number:int");
        }
        static d(a) {
            DataGridSummaryResultDescriptionMetadata.b(a);
            a.ac("DataGridSummaryResult", () => new DataGridSummaryResultDescription());
            a.ab("DataGridSummaryResult", DataGridSummaryResultDescriptionMetadata.a);
        }
    }
    DataGridSummaryResultDescriptionMetadata.$t = /*@__PURE__*/ markType(DataGridSummaryResultDescriptionMetadata, 'DataGridSummaryResultDescriptionMetadata');
    DataGridSummaryResultDescriptionMetadata.a = null;
    return DataGridSummaryResultDescriptionMetadata;
})();
